==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/app/translations/qmmp_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="68"/>
        <source>Skip forward in playlist</source>
        <translation>Přejít vpřed v seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="69"/>
        <source>Skip backwards in playlist</source>
        <translation>Přejít zpět v seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Start playing current song</source>
        <translation>Spustit přehrávání aktuální skladby</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Don&apos;t clear the playlist</source>
        <translation type="unfinished">Nevyprazdňovat seznam skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Pause current song</source>
        <translation>Pozastavit aktuální skladbu</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pozastavit, přehrává-li se, jinak přehrávat</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Stop current song</source>
        <translation>Zastavit aktuální skladbu</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Display Jump to File dialog</source>
        <translation>Zobrazit dialog Přeskočit na soubor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="66"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="67"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nastavit hlasitost přehrávání (příklad: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="70"/>
        <source>Show/hide application</source>
        <translation>Zobrazit/skrýt aplikaci</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Display Add File dialog</source>
        <translation>Zobrazit dialog Přidat soubor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Display Add Directory dialog</source>
        <translation>Zobrazit dialog Přidat adresář</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="287"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Použití: qmmp [volby] [soubory]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="288"/>
        <source>Options:</source>
        <translation>Volby:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="292"/>
        <source>Don&apos;t start the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="294"/>
        <source>Print version number and exit</source>
        <translation>Vypsat číslo verze a skončit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="295"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Nápady, patche, hlášení chyb posílejte na forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="300"/>
        <source>QMMP version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="301"/>
        <source>Compiled with Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="302"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="293"/>
        <source>Display this text and exit</source>
        <translation>Zobrazit tento text a skončit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="83"/>
        <source>Unknown command</source>
        <translation>Neznámý příkaz</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/app/translations/qmmp_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="70"/>
        <source>Skip forward in playlist</source>
        <translation>Přejít vpřed v seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Skip backwards in playlist</source>
        <translation>Přejít zpět v seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Start playing current song</source>
        <translation>Spustit přehrávání aktuální skladby</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nevyprazdňovat seznam skladeb</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Pause current song</source>
        <translation>Pozastavit aktuální skladbu</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pozastavit, přehrává-li se, jinak přehrávat</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="66"/>
        <source>Stop current song</source>
        <translation>Zastavit aktuální skladbu</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="67"/>
        <source>Display Jump to File dialog</source>
        <translation>Zobrazit dialog Přeskočit na soubor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="68"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="69"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nastavit hlasitost přehrávání (příklad: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Show/hide application</source>
        <translation>Zobrazit/skrýt aplikaci</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Display Add File dialog</source>
        <translation>Zobrazit dialog Přidat soubor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Display Add Directory dialog</source>
        <translation>Zobrazit dialog Přidat adresář</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="286"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Použití: qmmp [volby] [soubory]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="287"/>
        <source>Options:</source>
        <translation>Volby:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="291"/>
        <source>Don&apos;t start the application</source>
        <translation>Nespouštět aplikaci</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="293"/>
        <source>Print version number and exit</source>
        <translation>Vypsat číslo verze a skončit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="294"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Nápady, patche, hlášení chyb posílejte na forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="299"/>
        <source>QMMP version: %1</source>
        <translation>QMMP verze: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="300"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Zkompilováno s Qt verze: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="301"/>
        <source>Using Qt version: %1</source>
        <translation>Používá Qt verze: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="292"/>
        <source>Display this text and exit</source>
        <translation>Zobrazit tento text a skončit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="83"/>
        <source>Unknown command</source>
        <translation>Neznámý příkaz</translation>
    </message>
</context>
</TS>
